#
#
# $Id: gtkmisc.rb,v 1.12 2003/12/09 16:10:47 Yuukis Exp $
#
#

module GtkExt
	
	class Windmill < Gtk::Button  #=> Thread Manager for C.i.
		def initialize
			@ab = Pix.get('about')
			@wind = []
			['load', 'load+1', 'load+2', 'load+1',
			 'load', 'load-1', 'load-2', 'load-1'].each {|i| @wind << Pix.get(i)}
			super()
			add @ab
			set_usize(22, 16)
			@thr = Thread.fork { Thread.exit }
			@q = []
		end
	
		def start(purpose = '')
			if @q.include?(purpose)
				return(false) #=> already.
			else
				if @q.empty?
					@thr = Thread.fork {
						show_all
						while true
							@wind.each {|w| remove child; add(w).show_all ; sleep 0.5 }
						end
					}
				end
				@q << purpose
				return(true) #=> OK.
			end
		end
	
		def stop(purpose = '')
			@q.delete(purpose)
			if @q.empty?
				@thr.kill if @thr.alive?
				remove child
				add @ab
			end
		end
	
		def kill
			@thr.kill if @thr.alive?
				remove child
				add @ab
			@q.clear
		end
	
		def q
			return(@q)
		end
	end


	class UrlView < Gtk::Combo  # for C.i.
		include Searched

		def initialize
			super()
			entry.set_editable(true)
			disable_activate
			set_use_arrows_always(true)
			set_case_sensitive(false)
			set_popdown_strings([''])
		end
	
		def set_board(board)
			set_popdown_strings(get_searched(board))
		end
	
		def add_str(board, str)
			x = entry.get_text
			add_searched(board, str) if str != ""
			set_board(board)
			entry.set_text(x)
		end
	end


	class TopButtons < Gtk::HBox # for C.i.
		attr_reader :select, :bookmark, :reload, :cancel, :find, :exit, :check, :followup
		attr_reader :urlview, :windmill

		def initialize

			@select = Gtk::ToggleButton.new.add Pix.get('boardselect')
				GtkExt.set_tooltip(@select, CFG::NLS.ttg_select)
			@bookmark = Gtk::ToggleButton.new.add Pix.get('bookmark')
				GtkExt.set_tooltip(@bookmark, CFG::NLS.ttg_bookmark)
			@reload = Gtk::Button.new.add Pix.get('refresh_blue')
				GtkExt.set_tooltip(@reload, CFG::NLS.ttg_reload)
			@cancel = Gtk::Button.new.add Pix.get('cancel')
				GtkExt.set_tooltip(@cancel, CFG::NLS.ttg_cancel)
			@find = Gtk::Button.new.add Pix.get('search')
				GtkExt.set_tooltip(@find, CFG::NLS.ttg_find)
			@exit = Gtk::Button.new.add Pix.get('exit')
				GtkExt.set_tooltip(@exit, CFG::NLS.ttg_exit)
			@check = Gtk::CheckButton.new
				GtkExt.set_tooltip(@check, CFG::NLS.ttg_check)
			@followup = Gtk::Button.new.add Pix.get('edit')
				GtkExt.set_tooltip(@followup, CFG::NLS.ttg_followup)

			@urlview = UrlView.new
			@windmill = Windmill.new

			super()
			pack_start @select, false
			pack_start @bookmark, false
			pack_start @reload, false
			pack_start @cancel, false
			pack_start @followup, false
			pack_start @exit, false
			pack_start @check, false
			pack_start @urlview, true
			pack_start @find, false
			pack_start @windmill, false
		end
	end


	class About < Gtk::Window
		def initialize
			super()
	
			v_str =  "#{CiLongString.sub('version', "\nversion")}\n"
			v_str << "Send mail <Ys@PixyGarden.net> for contact.\n"
			v_str << "Visit http://wids.net/lab/Ci.html for updates.\n\n"
			v_str << "(C)2003 H.Miyamoto (aka \"Yuukis\")\n"
			v_label = Gtk::Label.new(v_str)
	
			close = Gtk::Button.new("\s"*5 + "OK" + "\s"*5)
			close.signal_connect('clicked') { destroy }
			bbox = Gtk::HBox.new
			bbox.pack_start Gtk::Label.new('')
			bbox.pack_start close, false
	
			xbox = Gtk::VBox.new
			xbox.pack_start v_label
			xbox.pack_start bbox, false
	
			box = Gtk::VBox.new(false, 10)
			box.border_width = 8
			box.pack_start Pix.get('logo')
			box.pack_start xbox
			add box
			set_title('About C.i.')
			set_focus(close)
			signal_connect('delete_event') { destroy }
			self
		end
	end
	

	class ConfigPop < Gtk::Menu
	
		attr_reader :update_bbsmenu, :stype, :hide, :config, :about
	
		def initialize
			super()
	
			@update_bbsmenu = Gtk::MenuItem.new(CFG::NLS.ttc_update)
			@stype = Gtk::MenuItem.new(CFG::NLS.ttc_stype)
			@hide = Gtk::MenuItem.new(CFG::NLS.ttc_hide)
			@config = Gtk::MenuItem.new(CFG::NLS.ttc_config)
			@about = Gtk::MenuItem.new(CFG::NLS.ttc_about)
	
			append @update_bbsmenu
			append @stype
			append @hide
			append @config
			append @about
	
			show_all
		end
	end


	module Menus  # for ThreadFrame AA / Filter
		def Menus.init(tooltip, name)
			button = Gtk::MenuBar.new
			GtkExt.set_tooltip(button, tooltip)
			menu_root = Gtk::MenuItem.new.add Gtk::Label.new(name)
			button.append(menu_root)
			menu = Gtk::Menu.new
			menu_root.set_submenu(menu)
			return([button, menu_root, menu])
		end
	end

	
	class FollowPop < Gtk::Menu  # for ThreadFrame
		def initialize(str)
			super()
			fs = Gtk::MenuItem.new(str)
			fs.child.set_justify(Gtk::JUSTIFY_LEFT)
			fs.signal_connect('button_press_event'){
				popdown
			}
	
			append Gtk::MenuItem.new
			append fs
			append Gtk::MenuItem.new
	
			show_all
		end
	end


	class RightMenu < Gtk::Menu  # for SubjectFrame
		attr_reader :title, :bookmark, :abone

		def initialize(title)
			super()
			@title = Gtk::MenuItem.new(title)
			self.append @title
			self.append Gtk::MenuItem.new
			@bookmark = Gtk::MenuItem.new('')
			self.append @bookmark
			@abone = Gtk::MenuItem.new('')
			self.append @abone
	
			self.show_all
		end
	end
end
